==> haskell-hls-retrie-plugin-1.0.1.1-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-retrie-plugin
version:              1.0.1.1
visibility:           public
id:                   hls-retrie-plugin-1.0.1.1-Cod7KP5EqpiD3NpElXRJWa
key:                  hls-retrie-plugin-1.0.1.1-Cod7KP5EqpiD3NpElXRJWa
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  612a794715595f85c99e8ca9285132b4
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hls-retrie-plugin-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hls-retrie-plugin-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-1.0.1.1-Cod7KP5EqpiD3NpElXRJWa
depends:
    aeson-1.5.6.0-ACA5il8oUDTGWSuengtGRp base-4.15.1.0
    containers-0.6.4.1 deepseq-1.4.5.0 directory-1.3.6.2
    extra-1.7.10-Ftra9IdqTdp95PiG9UbAhf ghc-9.0.2
    ghc-api-compat-8.6.1-F4jVXTaEYzcGEcFzzf0nwC
    ghcide-1.4.1.0-8Sp6u3DAgJh9tj901MDyK5
    hashable-1.4.0.0-Ad25gOPS1LBBwFTwmctznB
    hls-plugin-api-1.2.0.0-GP7xvMizolV1cT9PyuVmju
    lsp-1.2.0.1-8esNiqhpTKl89loDFNHlHJ
    lsp-types-1.3.0.1-9mi6Vpok1mP74eGK1TdVBK
    retrie-1.1.0.0-5tUYnKVgtrsLImBBakhY3C
    safe-exceptions-0.1.7.2-CBfZQcIqSYDK2MNuGjYQ4H text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.18.0-HgeMTnP7CmhGWtqS52RLit

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-retrie-plugin-1.0.1.1-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-retrie-plugin
version:              1.0.1.1
visibility:           public
id:                   hls-retrie-plugin-1.0.1.1-F1HIc7jq4jt8KQrfSCHziZ
key:                  hls-retrie-plugin-1.0.1.1-F1HIc7jq4jt8KQrfSCHziZ
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cdb798c8bcd394613be491b58deb5373
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hls-retrie-plugin-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hls-retrie-plugin-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-1.0.1.1-F1HIc7jq4jt8KQrfSCHziZ
depends:
    aeson-1.5.6.0-C19GJXDSM92LJPi4EK7PL5 base-4.15.1.0
    containers-0.6.4.1 deepseq-1.4.5.0 directory-1.3.6.2
    extra-1.7.10-KevpvDyc8Q4J7ykyOngBIs ghc-9.0.2
    ghc-api-compat-8.6.1-F4jVXTaEYzcGEcFzzf0nwC
    ghcide-1.4.1.0-LrtQxnzNTMiDzDWJ8lJOGH
    hashable-1.4.0.1-4LYnLqhVCzaKURVgzlvekc
    hls-plugin-api-1.2.0.0-LxveDhyoOPvLZURI3nILqo
    lsp-1.2.0.1-6QOZMcDyuubBNZMdmm8uA2
    lsp-types-1.3.0.1-JgjoXDMMhsXIXMSXzpEEwC
    retrie-1.1.0.0-1KgALoizIni2o4oDduj5xv
    safe-exceptions-0.1.7.2-Hutg7xs7vUP7qXuGIKI5fp text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.18.0-5g7cvfJKetKCmnCFTnDbJb

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
